==> nativescript-ui-dataform-3.7.1.tgz: package/README.md <==
# NativeScript UI DataForm

- [Overview](#overview)
- [Installation](#installation)
- [Documentation](#documentation)
- [API Reference](#api-reference)
- [Sample Apps](#sample-apps)
- [Release Notes](#release-notes)
- [Get Help](#get-help)


## Overview

**NativeScript UI DataForm** is part of [Progress NativeScript UI](https://www.nativescript.org/ui-for-nativescript) - a suite of rich-UI components targeting the NativeScript platform.

The **NativeScript UI DataForm** plugin provides an easy and versatile approach for building mobile forms based on a provided data object's public members. Use DataForm to:

* Bind a form to a data object with a single line of code;
* Take advantage of more than 15 built-in editors (or provide your own custom editor);
* Create groups of editors, allow them to be collapsed and style them;
* Display a form in ReadOnly mode;
* Take control over collected data with built-in data validation - use a provided validator or create a custom one.

<img src="https://docs.nativescript.org/img/ui-for-nativescript/dataform-ios.png"><img src="https://docs.nativescript.org/img/ui-for-nativescript/dataform-android.png">

## Installation

In Command prompt / Terminal navigate to your application root folder and run:

```
tns plugin add nativescript-ui-dataform
```

## Documentation

To use the DataForm plugin, you need to add an instance of `RadDataForm` and bind the `source` property to your business object that you want to edit with the form.
More information is available in the Guides for [NativeScript Core](http://docs.telerik.com/devtools/nativescript-ui/Controls/NativeScript/DataForm/dataform-overview) and [NativeScript with Angular](http://docs.telerik.com/devtools/nativescript-ui/Controls/Angular/DataForm/dataform-overview).

## API Reference

[Here](http://docs.telerik.com/devtools/nativescript-ui/api/classes/raddataform.html) is the API Reference section.

## Sample Apps

The features of the plugin are demonstrated in the Sample apps for [NativeScript Core](https://github.com/telerik/nativescript-ui-samples) and [NativeScript with Angular](https://github.com/telerik/nativescript-ui-samples-angular).

## Release Notes

The release notes are available [here](https://github.com/telerik/nativescript-ui-feedback/blob/master/releases/dataform.md).

## Get Help

Please, use [github issues](https://github.com/telerik/nativescript-ui-feedback/issues) strictly for reporting bugs or requesting features.

==> nativescript-ui-dataform-4.0.0.tgz: package/README.md <==
# NativeScript UI DataForm

- [Overview](#overview)
- [Installation](#installation)
- [Documentation](#documentation)
- [API Reference](#api-reference)
- [Sample Apps](#sample-apps)
- [Release Notes](#release-notes)
- [Get Help](#get-help)


## Overview

**NativeScript UI DataForm** is part of [Progress NativeScript UI](https://www.nativescript.org/ui-for-nativescript) - a suite of rich-UI components targeting the NativeScript platform.

The **NativeScript UI DataForm** plugin provides an easy and versatile approach for building mobile forms based on a provided data object's public members. Use DataForm to:

* Bind a form to a data object with a single line of code;
* Take advantage of more than 15 built-in editors (or provide your own custom editor);
* Create groups of editors, allow them to be collapsed and style them;
* Display a form in ReadOnly mode;
* Take control over collected data with built-in data validation - use a provided validator or create a custom one.

<img src="https://docs.nativescript.org/img/ui-for-nativescript/dataform-ios.png"><img src="https://docs.nativescript.org/img/ui-for-nativescript/dataform-android.png">

## Installation

In Command prompt / Terminal navigate to your application root folder and run:

```
tns plugin add nativescript-ui-dataform
```

## Documentation

To use the DataForm plugin, you need to add an instance of `RadDataForm` and bind the `source` property to your business object that you want to edit with the form.
More information is available in the Guides for:
- [NativeScript Core](https://docs.nativescript.org/ui/professional-ui-components/DataForm/dataform-overview)
- [NativeScript with Angular](https://docs.nativescript.org/angular/ui/professional-ui-components/ng-DataForm/dataform-overview)
- [NativeScript with Vue.js](https://docs.nativescript.org/vuejs/ns-ui/DataForm/overview)

## API Reference

[Here](https://docs.nativescript.org/ns-ui-api-reference/classes/raddataform) is the API Reference section.

## Sample Apps

The features of the plugin are demonstrated in the Sample apps for:
- [NativeScript Core](https://github.com/telerik/nativescript-ui-samples)
- [NativeScript with Angular](https://github.com/telerik/nativescript-ui-samples-angular)
- [NativeScript with Vue.js](https://github.com/telerik/nativescript-ui-samples-vue)

## Release Notes

The release notes are available [here](https://github.com/telerik/nativescript-ui-feedback/blob/master/releases/dataform.md).

## Get Help

Please, use [github issues](https://github.com/telerik/nativescript-ui-feedback/issues) strictly for reporting bugs or requesting features.
